@@ -7,7 +7,7 @@ class Converter:
         self.cities = json.load(cities_file)
 
     def decode(self, pluscode):
-        match = re.match('^(\S*\S{2})\s*(.*?),\s*(\S*)$', pluscode)
+        match = re.match('^(\S*\S{2})\s*(.*?),\s*(.*)$', pluscode)
         if match is None:
             return False
         if len(match.groups()) > 1:
